OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Додадени во фаворити",
    "Removed from favorites" : "Отстранети од фаворити",
    "You added {file} to your favorites" : "Додадовте {file} во фаворити",
    "You removed {file} from your favorites" : "Отстранивте {file} од фаворити",
    "Favorites" : "Омилени",
    "File changes" : "Промени на датотеки",
    "Created by {user}" : "Копирано од {user}",
    "Changed by {user}" : "Променето од {user}",
    "Deleted by {user}" : "Избришано од {user}",
    "Restored by {user}" : "Вратено од {user}",
    "Renamed by {user}" : "Преименувано од {user}",
    "Moved by {user}" : "Преместено од {user}",
    "You created {file}" : "Креиравте {file}",
    "You created an encrypted file in {file}" : "Креиравте шифрирана датотека во {file}",
    "{user} created {file}" : "{user} креираше {file}",
    "{user} created an encrypted file in {file}" : "{user} креираше шифрирана датотека во {file}",
    "{file} was created in a public folder" : "{file} е креиран во јавна папка",
    "You changed {file}" : "Изменивте {file}",
    "You changed an encrypted file in {file}" : "Изменивте шифрирана дататека во {file}",
    "{user} changed {file}" : "{user} измени {file}",
    "{user} changed an encrypted file in {file}" : "{user} измени шифрирана дататека во {file}",
    "You deleted {file}" : "Избришавте {file}",
    "You deleted an encrypted file in {file}" : "Избришавте шифрирана датотека во {file}",
    "{user} deleted {file}" : "{user} избриша {file}",
    "{user} deleted an encrypted file in {file}" : "{user} избриша шифрирана датотека во {file}",
    "You restored {file}" : "Вративте {file}",
    "{user} restored {file}" : "{user} врати {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Го преименувавте {oldfile} (hidden) во {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Го преименувавте {oldfile} (hidden) во {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Го преименувавте {oldfile} во {newfile} (hidden)",
    "You renamed {oldfile} to {newfile}" : "Го преименувавте {oldfile} во {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} го преимени {oldfile} (hidden) во {newfile} (hidden)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} го преимени {oldfile} (hidden) во {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} го преимени {oldfile} во {newfile} (hidden)",
    "{user} renamed {oldfile} to {newfile}" : "{user} го преимени {oldfile} во {newfile}",
    "You moved {oldfile} to {newfile}" : "Го премести {oldfile} во {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} го премести {oldfile} во {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Датотека беше додадена или избришана од  <strong>фаворити</strong>",
    "Files" : "Датотеки",
    "A file or folder has been <strong>changed</strong>" : "Датотека или папка беше <strong>променета</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Датотека или папка која е означена како омилена беше <strong>променета</strong>",
    "Upload (max. %s)" : "Префрлање (макс. %s)",
    "Accept" : "Прифати",
    "Reject" : "Одбиј",
    "Incoming ownership transfer from {user}" : "Барање за трансфер на сопственост од {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Дали прифаќате {path}?\n\nЗабелешка: Процесот на трансфер откога ќе прифатите може да трае и повеќе од 1 час.",
    "Ownership transfer failed" : "Неуспешен трансфер на сопственост",
    "Your ownership transfer of {path} to {user} failed." : "Неуспешен трансфер на сопственост на {path} до {user}.",
    "The ownership transfer of {path} from {user} failed." : "Неуспешен трансфер на сопственост на {path} од {user}.",
    "Ownership transfer done" : "Направено е трансфер на сопственост",
    "Your ownership transfer of {path} to {user} has completed." : "Вашиот транфер на сопственост на {path} до {user} е комплетиран.",
    "The ownership transfer of {path} from {user} has completed." : "Трансферот на сопственост на {path} од {user} е комплетиран.",
    "in %s" : "во %s",
    "File Management" : "Датотеки",
    "Current directory path" : "Патека до оваа папка",
    "Home" : "Дома",
    "Target folder does not exist any more" : "Папката не постои повеќе",
    "Reload current directory" : "Превчитај ја повторно моменталната папка",
    "Go to the \"{dir}\" directory" : "Оди до \"{dir}\" папката",
    "Drag and drop files here to upload" : "Повлечи и испушти датотеки за прикачување",
    "Your have used your space quota and cannot upload files anymore" : "Го имате искористено лимитот на просторот за прикачување и повеќе неможете да прикачувате датотеки",
    "You don’t have permission to upload or create files here" : "Немате дозвола да прикачувате или да креирате датотеки",
    "Favorite" : "Омилени",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" акцијата е успешно извршена",
    "\"{displayName}\" action failed" : "\"{displayName}\" акцијата не успеа",
    "Rename file" : "Преименувај датотека",
    "Filename" : "Име на датотека",
    "Folder name" : "Име на папка",
    "This node is unavailable" : "Нодот е недостапен",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Преименувано \"{oldName}\" во \"{newName}\"",
    "Pending" : "Чека",
    "Clear filter" : "Исчисти филтри",
    "Modified" : "Променето",
    "Type" : "Вид",
    "Total rows summary" : "Резиме на вкупно редови",
    "Name" : "Име",
    "Size" : "Големина",
    "Actions" : "Акции",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\" не успеа на некои елементи",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" сериската акцијата е успешно извршена",
    "{count} selected" : "{count} селектирани",
    "List of files and folders." : "Листа на датотеки и папки.",
    "Column headers with buttons are sortable." : "Насловите на колоните со копчиња се сортираат.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Оваа листа не е целосно прикажана поради заштеда на перформанси. Датотеките ќе се прикажуваат додека се движите низ листата.",
    "File not found" : "Датотеката не е пронајдена",
    "Storage information" : "Информации за складиште",
    "{usedQuotaByte} used" : "искористено {usedQuotaByte}",
    "{used} of {quota} used" : "Искористени {used} од {quota}",
    "{relative}% used" : "искористено {relative}% ",
    "Could not refresh storage stats" : "Неможе да се ажурира статистиката за складиштата",
    "Your storage is full, files can not be updated or synced anymore!" : "Вашето складиште е исполнето, датотеките веќе не можат да се ажирираат или синхронизираат!",
    "Create" : "Креирај",
    "New folder" : "Нова папка",
    "Create new folder" : "Креирај нова папка",
    "Submit" : "Испрати",
    "Transfer ownership of a file or folder" : "Трансфер на сопственост на датотека или папка",
    "Choose file or folder to transfer" : "Избери датотека или папка за трансфер",
    "Change" : "Измени",
    "New owner" : "Нов сопственик",
    "Choose a file or folder to transfer" : "Избери датотека или папка за трансфер",
    "Transfer" : "Трансфер",
    "Transfer {path} to {userid}" : "Трансфер {path} до {userid}",
    "Invalid path selected" : "Избрана невалидна патека",
    "Unknown error" : "Непозната грешка",
    "Ownership transfer request sent" : "Испратено барање за трансфер на сопственост",
    "Cannot transfer ownership of a file or folder you do not own" : "Неможете да направите трансвер на сопственот на папка која не е ваша",
    "Select file or folder to link to" : "Изберете датотека или папка за линк до",
    "Choose {file}" : "Избери {file}",
    "New" : "Ново",
    "Loading current folder" : "Вчитување на моменталната папка",
    "Retry" : "Обидете се повторно",
    "No files in here" : "Тука нема датотеки",
    "Upload some content or sync with your devices!" : "Прикачете некоја содржина или синхронизирајте со вашите уреди!",
    "Go back" : "Назад",
    "Share" : "Сподели",
    "Shared by link" : "Споделено со линк",
    "Shared" : "Споделено",
    "Switch to list view" : "Прикажи поглед во листа",
    "Switch to grid view" : "Прикажи поглед во мрежа",
    "Not enough free space" : "Нема доволно слободен простор",
    "Operation is blocked by access control" : "Операцијата е блокирана од контролата на пристап",
    "Error during upload: {message}" : "Грешка при прикачување: {message}",
    "Unknown error during upload" : "Непозната грешка при прикачување",
    "Views" : "Прегледи",
    "Files settings" : "Параметри за датотеки",
    "File cannot be accessed" : "Неможе да се пристапи до датотеката",
    "Sort favorites first" : "Прво омилените",
    "Show hidden files" : "Прикажи сокриени датотеки",
    "Crop image previews" : "Исечи ја сликата за преглед",
    "Enable the grid view" : "Овозможи поглед во мрежа",
    "Additional settings" : "Дополнителни параметри",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV адреса",
    "Copy to clipboard" : "Копирај во клипборд",
    "Use this address to access your Files via WebDAV" : "Користи ја оваа адреса за пристап до вашите датотеки преку WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ако имате овозможено 2FA, мора да креирате и користите нова лозинка за апликација со кликнување овде.",
    "Clipboard is not available" : "Клипбордот не е достапен",
    "WebDAV URL copied to clipboard" : "CalDAV линкот е копиран",
    "Remove from favorites" : "Отстрани од фаворити",
    "Add to favorites" : "Додади во фаворити",
    "Tags" : "Ознаки",
    "You" : "Вие",
    "Unable to change the favourite state of the file" : "Неможе да се промени статусот на омимени на датотеката",
    "Error while loading the file data" : "Грешка при вчитување на податоците од датотеката",
    "Pick a template for {name}" : "Избери шаблон за {name}",
    "Create a new file with the selected template" : "Креирај нова датотека со избраниот шаблон",
    "Creating file" : "Креирање на датотека",
    "Blank" : "Празно",
    "Unable to create new file from template" : "Неможе да се креира датотека од шаблон",
    "Delete permanently" : "Избриши",
    "Disconnect storage" : "Исклучи складиште",
    "Delete file" : "Избриши датотека",
    "Delete files" : "Избриши датотеки",
    "Delete folder" : "Избриши папка",
    "Delete folders" : "Избриши папки",
    "Delete" : "Избриши",
    "Confirm deletion" : "Потврди бришење",
    "Cancel" : "Откажи",
    "Edit file locally" : "Уреди ја датотеката локално",
    "Failed to redirect to client" : "Неуспешно пренасочување кон клиентот",
    "Edit locally" : "Уреди локално",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Неможете да преместите датотека/папка во себеси или во подпапка во себеси",
    "(copy)" : "(копирај)",
    "(copy %n)" : "(копирај %n)",
    "A file or folder with that name already exists in this folder" : "Датотека или папка со тоа име веќе постои во оваа папка",
    "The files are locked" : "Датотекатите се заклучени",
    "The file does not exist anymore" : "Датотеката не постои",
    "Choose destination" : "Избери дестинација",
    "Copy to {target}" : "Копирај во {target}",
    "Copy" : "Копирај",
    "Move to {target}" : "Премести во {target}",
    "Move" : "Премести",
    "Move or copy" : "Премести или копирај",
    "Cancelled move or copy operation" : "Откажана операција на копирање или преместување",
    "Open folder {displayName}" : "Отвори папка {displayName}",
    "Open in Files" : "Отвори во датотеките",
    "Rename" : "Преименувај",
    "Open details" : "Отвори детали",
    "View in folder" : "Погледни во папката",
    "Today" : "Денес",
    "Last 7 days" : "Предходни 7 дена",
    "Last 30 days" : "Предходни 30 дена",
    "This year ({year})" : "Оваа година ({year})",
    "Last year ({year})" : "Минатата година ({year})",
    "Documents" : "Документи",
    "Folders" : "Папки",
    "Audio" : "Аудио",
    "Videos" : "Видеа",
    "Created new folder \"{name}\"" : "Креирана нова папка \"{name}\"",
    "Unable to initialize the templates directory" : "Не може да се иницијализира папка за шаблони",
    "Templates" : "Шаблони",
    "One of the dropped files could not be processed" : "Една од испуштените датотеки неможе да се процесоира",
    "Some files could not be moved" : "Некои датотеки не можат да се преместат",
    "This operation is forbidden" : "Операцијата не е дозволена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Овој директориум е недостапен, ве молиме проверете ги логовите или контактирајте со администраторот",
    "Storage is temporarily not available" : "Складиштето моментално не е достапно",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} папка","{folderCount} папки"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} датотека","{fileCount} датотеки"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 датотека и {folderCount} папки","1 датотека и {folderCount} папки"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} датотека и 1 папка","{fileCount} датотеки и 1 папка"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} датотеки и {folderCount} папки",
    "No favorites yet" : "Сеуште нема фаворити",
    "Files and folders you mark as favorite will show up here" : "Датотеките и папките кои ќе ги означите како чести, ќе се појават тука",
    "All files" : "Сите датотеки",
    "List of your files and folders." : "Листа на вашите датотеки и папки.",
    "All folders" : "Сите папки",
    "Personal Files" : "Персонални датотеки",
    "Recent" : "Неодамнешни",
    "List of recently modified files and folders." : "Листа на скоро изменети датотеки и папки.",
    "No recently modified files" : "Нема скоро изменети датотеки",
    "Files and folders you recently modified will show up here." : "Датотеките и папките кои скоро ќе ги измените ќе се појават тука.",
    "You do not have permission to upload or create files here" : "Немате дозвола да прикачувате или да креирате датотеки овде",
    "No entries found in this folder" : "Нема ништо во оваа папка",
    "Select all" : "Избери се",
    "Upload too large" : "Фајлот кој се вчитува е преголем",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Датотеките кои се обидувате да ги подигнете ја надминуваат максималната големина за подигнување датотеки на овој сервер.",
    "File could not be found" : "Неможе да се пронајде датотеката",
    "Download" : "Преземи",
    "Show list view" : "Прикажи поглед во листа",
    "Show grid view" : "Прикажи поглед во мрежа",
    "Close" : "Затвори",
    "Could not create folder \"{dir}\"" : "Неможе да се креира папка \"{dir}\"",
    "This will stop your current uploads." : "Ова ќе го прекине вашето моментално прикачување.",
    "Upload cancelled." : "Преземањето е прекинато.",
    "Processing files …" : "Обработка на датотеки ...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неможе да се прикачи {filename} бидејќи е директориум или е 0 бајти",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Нема доволно слободен простор, прикачувате {size1} а слободен простор има {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Папката \"{dir}\" не постои повеќе",
    "An unknown error has occurred" : "Се појави непозната грешка",
    "File could not be uploaded" : "Датотеката неможе да се прикачи",
    "Uploading …" : "Прикачување …",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Прикачување … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} од {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Прикачување на таа датотека не е дозволено",
    "Error when assembling chunks, status code {status}" : "Грешка при составување на парчиња, статусен код {status}",
    "Choose target folder" : "Избери папка",
    "Set reminder" : "Постави потсетник",
    "Open" : "Отвори",
    "Could not load info for file \"{file}\"" : "Неможе да се вчитаат информации за датотеката \"{file}\"",
    "Details" : "Детали:",
    "Please select tag(s) to add to the selection" : "Избери ознаки за одбележаното",
    "Apply tag(s) to selection" : "Примени ознаки на обележаните",
    "Select directory \"{dirName}\"" : "Избери папка \"{dirName}\"",
    "Select file \"{fileName}\"" : "Избери датотека \"{fileName}\"",
    "Unable to determine date" : "Неможе да се одреди датумот",
    "Could not move \"{file}\", target exists" : "Не може да се премести \"{file}\", веќе постои",
    "Could not move \"{file}\"" : "Не може да се премести \"{file}\"",
    "copy" : "копирај",
    "Could not copy \"{file}\", target exists" : "Не може да се копира \"{file}\", веќе постои",
    "Could not copy \"{file}\"" : "Не може да се копира \"{file}\"",
    "Copied {origin} inside {destination}" : "Копирана {origin} во {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Копирана {origin} и {nbfiles} други датотеки во {destination}",
    "{newName} already exists" : "{newName} веќе постои",
    "Could not rename \"{fileName}\", it does not exist any more" : "Неможе да се преименува \"{fileName}\", датотеката не постои",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{targetName}\" веќе се користи во папката \"{dir}\". Ве молиме изберете друго име.",
    "Could not rename \"{fileName}\"" : "Неможе да се преименува \"{fileName}\"",
    "Could not create file \"{file}\"" : "Неможе да се креира датотека \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Неможе да се креира датотека \"{file}\" бидејќи веќе постои",
    "Could not create folder \"{dir}\" because it already exists" : "Неможе да се креира папка \"{dir}\" бидејќи веќе постои",
    "Could not fetch file details \"{file}\"" : "Неможе да се вчитаат деталите за датотеката \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Грешка при бришење на датотека \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нема резултати од пребарувањето на други места за {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Внесете повеќе од два карактери за да пребарувате во другите папки",
    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
    "_%n file_::_%n files_" : ["%n датотека","%n датотеки"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["вклучувајќи %n скриена","вклучувајќи %n скриени"],
    "_Uploading %n file_::_Uploading %n files_" : ["Прикачување %n датотека","Прикачување на %n датотеки"],
    "New file/folder menu" : "Мени Нова датотека/папка",
    "Select file range" : "Избери опсег на датотеки",
    "{used}%" : "{used}%",
    "{used} used" : "Искористени {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" е невалидно име за датотека.",
    "File name cannot be empty." : "Името на датотеката не може да биде празно.",
    "\"/\" is not allowed inside a file name." : "\"/\" не е дозволено во името.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" не е дозволен вид на датотека",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Складиштето на {owner} е исполнето, повеќе нема да може да сикхронизира и да прикачува датотеки!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Групната папка \"{mountPoint}\" е исполнета, датотеките веќе не можат да се ажирираат или синхронизираат!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Надворешното складиште \"{mountPoint}\" е исполнето, датотеките веќе не можат да се ажирираат или синхронизираат!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Вашето складиште е исполнето, датотеките веќе не можат да се ажирираат или синхронизираат!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Скалдиштето на {owner} е скоро исполнето ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Групната папка \"{mountPoint}\" е скоро исполнета ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Надворешното складиште \"{mountPoint}\" е скоро исполнето ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Вашето складиште е скоро исполнето ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["содржи '{filter}'","содржи '{filter}'"],
    "Direct link was copied (only works for users who have access to this file/folder)" : "Копиран е директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
    "Path" : "Патека",
    "_%n byte_::_%n bytes_" : ["%n бајт","%n бајти"],
    "Favorited" : "Омилени",
    "Copy direct link (only works for users who have access to this file/folder)" : "Копирај директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
    "Upload file" : "Прикачи датотека",
    "Not favorited" : "Нема фаворити",
    "An error occurred while trying to update the tags" : "Се случи грешка додека се обидувавте да ги освежите таговите",
    "\"remote user\"" : "\"далечен корисник\"",
    "{newName} already exists." : "{newName} веќе постои.",
    "Name cannot be empty" : "Името неможе да биде празно",
    "Another entry with the same name already exists" : "Друг запис со исто име веќе постои",
    "Could not rename \"{oldName}\", it does not exist any more" : "Неможе да се преименува \"{oldName}\", не постои повеќе",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{newName}\" веќе се користи во папката \"{dir}\". Ве молиме изберете друго име.",
    "Could not rename \"{oldName}\"" : "Неможе да се преименува \"{oldName}\"",
    "Storage informations" : "Информации за складиштето",
    "Choose file" : "Избери датотека",
    "Go to the previous folder" : "Врати се на предходната папка",
    "Open the files app settings" : "Отвори ги параметрите за датотеките",
    "You might not have have permissions to view it, ask the sender to share it" : "Можеби немате дозвола за преглед, прашајте го испраќачот за споделувањето",
    "The files is locked" : "Датотекатите се заклучени",
    "Create new templates folder" : "Креирај нова папка за шаблони",
    "List of favorites files and folders." : "Листа на омилени датотеки и папки.",
    "Toggle %1$s sublist" : "Вклучи %1$s подлисти",
    "Text file" : "Текстуална датотека",
    "New text file.txt" : "Нова текстуална датотека file.txt",
    "Direct link was copied (only works for people who have access to this file/folder)" : "Копиран е директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
    "Copy direct link (only works for people who have access to this file/folder)" : "Копирај директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
